===========================
 API Reference
===========================

:Release: |version|
:Date: |today|

Kombu Core
==========

.. toctree::
    :maxdepth: 1

    kombu
    kombu.common
    kombu.matcher
    kombu.mixins
    kombu.simple
    kombu.clocks
    kombu.compat
    kombu.pidbox
    kombu.exceptions
    kombu.log
    kombu.connection
    kombu.message
    kombu.compression
    kombu.pools
    kombu.abstract
    kombu.resource
    kombu.serialization

Kombu Transports
================

.. toctree::
    :maxdepth: 1

    kombu.transport
    kombu.transport.base
    kombu.transport.virtual
    kombu.transport.virtual.exchange
    kombu.transport.azurestoragequeues
    kombu.transport.azureservicebus
    kombu.transport.pyamqp
    kombu.transport.librabbitmq
    kombu.transport.qpid
    kombu.transport.memory
    kombu.transport.redis
    kombu.transport.mongodb
    kombu.transport.consul
    kombu.transport.etcd
    kombu.transport.zookeeper
    kombu.transport.filesystem
    kombu.transport.sqlalchemy
    kombu.transport.SQS
    kombu.transport.SLMQ
    kombu.transport.pyro


Kombu Asynchronous
==================

.. toctree::
    :maxdepth: 1

    kombu.asynchronous
    kombu.asynchronous.hub
    kombu.asynchronous.semaphore
    kombu.asynchronous.timer
    kombu.asynchronous.debug
    kombu.asynchronous.http
    kombu.asynchronous.http.base
    kombu.asynchronous.http.curl
    kombu.asynchronous.aws
    kombu.asynchronous.aws.connection
    kombu.asynchronous.aws.sqs
    kombu.asynchronous.aws.sqs.connection
    kombu.asynchronous.aws.sqs.message
    kombu.asynchronous.aws.sqs.queue

Kombu utils
===========

.. toctree::
    :maxdepth: 1

    kombu.utils.amq_manager
    kombu.utils.collections
    kombu.utils.compat
    kombu.utils.debug
    kombu.utils.div
    kombu.utils.encoding
    kombu.utils.eventio
    kombu.utils.functional
    kombu.utils.imports
    kombu.utils.json
    kombu.utils.limits
    kombu.utils.objects
    kombu.utils.scheduling
    kombu.utils.text
    kombu.utils.time
    kombu.utils.url
    kombu.utils.uuid
